smartcard.pyro.server.PyroEventServer.PyroEventServer

# ``smartcard`.`pyro`.`server`.`PyroEventServer`.`PyroEventServer``

class documentation

`class PyroEventServer(Thread):`

View In Hierarchy

Thread running the Pyro Event server.

Method | `__call__` | Ctrl+c handler that will gracefully shutdown the server upon Ctrl+C signal
Method | `__init__` | Initialize pyro event server with command line arguments. For a complete list of command line arguments, see pyro documentation for pyro-es start script.
Method | `run` | Starts Pyro naming server with command line arguments (see pyro documentation)
Method | `stop` | Shutdown pyro event server.
Method | `waitStarted` | wait until name server is started.
Instance Variable | `args` | Undocumented
Instance Variable | `handler` | Undocumented
Instance Variable | `starter` | Undocumented

def __call__(self, signame, sf):

Ctrl+c handler that will gracefully shutdown the server upon Ctrl+C signal

def __init__(self, args=[]):

Initialize pyro event server with command line arguments. For a complete list of command line arguments, see pyro documentation for pyro-es start script.

def run(self):

Starts Pyro naming server with command line arguments (see pyro documentation)

def stop(self):

Shutdown pyro event server.

def waitStarted(self):

wait until name server is started.

args =

Undocumented

handler =

Undocumented

starter =

Undocumented